![Github CI](https://github.com/flamingo-run/sanic-rest/workflows/Github%20CI/badge.svg)
[![Maintainability](https://api.codeclimate.com/v1/badges/0d6eb6158bc33aa2af1c/maintainability)](https://codeclimate.com/github/flamingo-run/sanic-rest/maintainability)
[![Test Coverage](https://api.codeclimate.com/v1/badges/0d6eb6158bc33aa2af1c/test_coverage)](https://codeclimate.com/github/flamingo-run/sanic-rest/test_coverage)
[![python](https://img.shields.io/badge/python-3.10-blue.svg)]()

# Sanic Rest Framework

## Installation

`pip install sanic-rest`
